@@ -607,8 +607,12 @@ sub process_file
     }
 
   create_temp("$tmpbase.3");
-  system ("$main::progs->{SGMLSASP} $style $mapping <\"$tmpbase.2\" |
-      expand -$global->{tabsize} >\"$tmpbase.3\"");
+  {
+      my $mycommand = "$main::progs->{SGMLSASP} $style $mapping <\"$tmpbase.2\" |
+      expand -t $global->{tabsize} >\"$tmpbase.3\"";
+      system ($mycommand) == 0
+	  or die "Error running $mycommand\n";
+  }
   ! -e "$tmpbase.3" and die "can't create file - exiting";
 
 
